'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var jsWeb3jsAdapters = require('@lorisleiva/js-web3js-adapters');
var ed25519 = require('@noble/ed25519');
var web3_js = require('@solana/web3.js');

function _interopNamespace(e) {
  if (e && e.__esModule) return e;
  var n = Object.create(null);
  if (e) {
    Object.keys(e).forEach(function (k) {
      if (k !== 'default') {
        var d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: function () { return e[k]; }
        });
      }
    });
  }
  n["default"] = e;
  return Object.freeze(n);
}

var ed25519__namespace = /*#__PURE__*/_interopNamespace(ed25519);

class Web3JsEddsa {
  generateKeypair() {
    return jsWeb3jsAdapters.fromWeb3JsKeypair(web3_js.Keypair.generate());
  }
  createKeypairFromSecretKey(secretKey) {
    return jsWeb3jsAdapters.fromWeb3JsKeypair(web3_js.Keypair.fromSecretKey(secretKey));
  }
  createKeypairFromSeed(seed) {
    return jsWeb3jsAdapters.fromWeb3JsKeypair(web3_js.Keypair.fromSeed(seed));
  }
  createPublicKey(input) {
    return jsWeb3jsAdapters.fromWeb3JsPublicKey(new web3_js.PublicKey(jsWeb3jsAdapters.toWeb3JsPublicKeyInput(input)));
  }
  createDefaultPublicKey() {
    return jsWeb3jsAdapters.fromWeb3JsPublicKey(web3_js.PublicKey.default);
  }
  isOnCurve(input) {
    return web3_js.PublicKey.isOnCurve(jsWeb3jsAdapters.toWeb3JsPublicKeyInput(input));
  }
  findPda(programId, seeds) {
    const [key, bump] = web3_js.PublicKey.findProgramAddressSync(seeds, new web3_js.PublicKey(jsWeb3jsAdapters.toWeb3JsPublicKeyInput(programId)));
    return {
      ...jsWeb3jsAdapters.fromWeb3JsPublicKey(key),
      bump
    };
  }
  sign(message, keypair) {
    return ed25519__namespace.sync.sign(message, keypair.secretKey.slice(0, 32));
  }
  verify(message, signature, publicKey) {
    return ed25519__namespace.sync.verify(signature, message, publicKey.bytes);
  }
}

exports.Web3JsEddsa = Web3JsEddsa;
//# sourceMappingURL=Web3JsEddsa.cjs.map
