import { fromWeb3JsKeypair, fromWeb3JsPublicKey, toWeb3JsPublicKeyInput } from '@lorisleiva/js-web3js-adapters';
import * as ed25519 from '@noble/ed25519';
import { Keypair, PublicKey } from '@solana/web3.js';

class Web3JsEddsa {
  generateKeypair() {
    return fromWeb3JsKeypair(Keypair.generate());
  }
  createKeypairFromSecretKey(secretKey) {
    return fromWeb3JsKeypair(Keypair.fromSecretKey(secretKey));
  }
  createKeypairFromSeed(seed) {
    return fromWeb3JsKeypair(Keypair.fromSeed(seed));
  }
  createPublicKey(input) {
    return fromWeb3JsPublicKey(new PublicKey(toWeb3JsPublicKeyInput(input)));
  }
  createDefaultPublicKey() {
    return fromWeb3JsPublicKey(PublicKey.default);
  }
  isOnCurve(input) {
    return PublicKey.isOnCurve(toWeb3JsPublicKeyInput(input));
  }
  findPda(programId, seeds) {
    const [key, bump] = PublicKey.findProgramAddressSync(seeds, new PublicKey(toWeb3JsPublicKeyInput(programId)));
    return {
      ...fromWeb3JsPublicKey(key),
      bump
    };
  }
  sign(message, keypair) {
    return ed25519.sync.sign(message, keypair.secretKey.slice(0, 32));
  }
  verify(message, signature, publicKey) {
    return ed25519.sync.verify(signature, message, publicKey.bytes);
  }
}

export { Web3JsEddsa };
//# sourceMappingURL=Web3JsEddsa.mjs.map
